==> kdevelop-4.6.90.tar.xz: kdevelop-4.6.90/providers/ghprovider/kdevghprovider.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=kdevgh
Exec=blubb
Comment=This plugin helps to obtain projects from Github
Comment[bs]=Ovaj dodatak pomaže da se dobave projekti s Github
Comment[ca]=Aquest connector ajuda a obtenir els projectes des de Github
Comment[ca@valencia]=Este connector ajuda a obtindre els projectes des de Github
Comment[da]=Dette plugin hjælper med at hente projekter fra Github
Comment[de]=Dieses Modul hilft dabei Github-Projekte zu beziehen
Comment[el]=Αυτό το πρόσθετο βοηθάει στην απόκτηση έργων από το Github
Comment[es]=Este complemento ayuda a obtener proyectos desde Github
Comment[et]=See plugin aitab hankida projekte Githubist
Comment[fi]=Tämä liitännäinen auttaa Github-projektien hakemisessa
Comment[fr]=Ce module externe permet d'obtenir des projets depuis Github
Comment[gl]=Este complemento permite obter proxectos de Github
Comment[hu]=Ez a bővítmény segít a projektek megszerzésében a Githubról
Comment[it]=Questa estensione consente di ottenere progetti da Github
Comment[kk]=Github жобаларын жүктеп алуға көмек плагині
Comment[nb]=Dette programtillegget hjelper til med å skaffe prosjekter fra Github
Comment[nl]=Deze plug-in helpt om projecten uit Github te verkrijgen
Comment[pl]=Wtyczka ta pomaga przy pobieraniu projektów z Githuba
Comment[pt]=Este 'plugin' ajuda a obter projectos do GitHub
Comment[pt_BR]=Este plugin ajuda a obter projetos a partir do Github
Comment[ru]=Это расширение помогает получать код проектов из Github
Comment[sk]=Tento modul pomáha získavať projekty z Github
Comment[sl]=Ta vstavek pomaga pri pridobivanju projektov iz Github-a
Comment[sv]=Insticksprogrammet hjälper till att erhålla projekt Github
Comment[uk]=За допомогою цього додатка можна отримувати проекти з Github
Comment[x-test]=xxThis plugin helps to obtain projects from Githubxx
Comment[zh_TW]=此外掛程式能協助您從 Github 取得專案
Name=Github Provider
Name[bs]=Github Provider
Name[ca]=Proveïdor de Github
Name[ca@valencia]=Proveïdor de Github
Name[cs]=Poskytovatel Github
Name[da]=Github-udbyder
Name[de]=Github-Provider
Name[el]=Πάροχος Github
Name[es]=Proveedor de Github
Name[et]=Github Provider
Name[fi]=Github-tarjoaja
Name[fr]=Fournisseur Github
Name[gl]=Fornecedor de Github
Name[hu]=Github szolgáltató
Name[it]=Fornitore Github
Name[kk]=Github таратушысы
Name[nb]=Github-leverandør
Name[nds]=Github-Anbeder
Name[nl]=Github-leverancier
Name[pl]=Dostawca Github
Name[pt]=Fornecedor do GitHub
Name[pt_BR]=Fornecedor do Github
Name[ru]=Поставщик проектов из Github
Name[sk]=Poskytovateľ Github
Name[sl]=Ponudnik za Github
Name[sv]=Github-leverantör
Name[uk]=Надавач даних Github
Name[x-test]=xxGithub Providerxx
Name[zh_TW]=Github 提供者
GenericName=Github Provider
GenericName[bs]=Github pružalac
GenericName[ca]=Proveïdor de Github
GenericName[ca@valencia]=Proveïdor de Github
GenericName[cs]=Poskytovatel Github
GenericName[da]=Github-udbyder
GenericName[de]=Github-Provider
GenericName[el]=Πάροχος Github
GenericName[es]=Proveedor de Github
GenericName[et]=Github Provider
GenericName[fi]=Github-tarjoaja
GenericName[fr]=Fournisseur Github
GenericName[gl]=Fornecedor de Github
GenericName[hu]=Github szolgáltató
GenericName[it]=Fornitore Github
GenericName[kk]=Github таратушысы
GenericName[nb]=Github-leverandør
GenericName[nds]=Github-Anbeder
GenericName[nl]=Github-leverancier
GenericName[pl]=Dostawca Github
GenericName[pt]=Fornecedor do GitHub
GenericName[pt_BR]=Fornecedor do Github
GenericName[ru]=Поставщик проектов из Github
GenericName[sk]=Poskytovateľ Github
GenericName[sl]=Ponudnik za Github
GenericName[sv]=Github-leverantör
GenericName[uk]=Надавач даних Github
GenericName[x-test]=xxGithub Providerxx
GenericName[zh_TW]=Github 提供者
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevghprovider
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevghprovider
X-KDE-PluginInfo-Author=Miquel Sabaté
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Mode=GUI
X-KDevelop-Interfaces=org.kdevelop.IProjectProvider

==> kdevelop_4.7.0.orig.tar.xz: kdevelop-4.7.0/providers/ghprovider/kdevghprovider.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=kdevgh
Exec=blubb
Comment=This plugin helps to obtain projects from Github
Comment[bs]=Ovaj dodatak omogućava dobijanje projekata iz Github
Comment[ca]=Aquest connector ajuda a obtenir els projectes des de Github
Comment[ca@valencia]=Este connector ajuda a obtindre els projectes des de Github
Comment[da]=Dette plugin hjælper med at hente projekter fra Github
Comment[de]=Dieses Modul hilft dabei, GitHub-Projekte zu beziehen
Comment[el]=Αυτό το πρόσθετο βοηθάει στην απόκτηση έργων από το Github
Comment[en_GB]=This plugin helps to obtain projects from Github
Comment[es]=Este complemento ayuda a obtener proyectos desde Github
Comment[et]=See plugin aitab hankida projekte Githubist
Comment[fi]=Tämä liitännäinen auttaa Github-projektien hakemisessa
Comment[fr]=Ce module externe permet d'obtenir des projets depuis Github
Comment[gl]=Este complemento permite obter proxectos de Github
Comment[hu]=Ez a bővítmény segít a projektek megszerzésében a Githubról
Comment[it]=Questa estensione consente di ottenere progetti da Github
Comment[kk]=Github жобаларын жүктеп алуға көмек плагині
Comment[nb]=Dette programtillegget hjelper til med å skaffe prosjekter fra Github
Comment[nl]=Deze plug-in helpt om projecten uit Github te verkrijgen
Comment[pl]=Wtyczka ta pomaga przy pobieraniu projektów z Githuba
Comment[pt]=Este 'plugin' ajuda a obter projectos do GitHub
Comment[pt_BR]=Este plugin ajuda a obter projetos a partir do Github
Comment[sk]=Tento modul pomáha získavať projekty z Github
Comment[sl]=Ta vstavek pomaga pri pridobivanju projektov iz Github-a
Comment[sv]=Insticksprogrammet hjälper till att erhålla projekt Github
Comment[uk]=За допомогою цього додатка можна отримувати проекти з Github
Comment[x-test]=xxThis plugin helps to obtain projects from Githubxx
Comment[zh_TW]=此外掛程式能協助您從 Github 取得專案
Name=Github Provider
Name[bs]=Github pružalac
Name[ca]=Proveïdor de Github
Name[ca@valencia]=Proveïdor de Github
Name[cs]=Poskytovatel Github
Name[da]=Github-udbyder
Name[de]=GitHub-Provider
Name[el]=Πάροχος Github
Name[en_GB]=Github Provider
Name[es]=Proveedor de Github
Name[et]=Githubi pakkuja
Name[fi]=Github-tarjoaja
Name[fr]=Fournisseur Github
Name[gl]=Fornecedor de Github
Name[hu]=Github szolgáltató
Name[it]=Fornitore Github
Name[kk]=Github таратушысы
Name[nb]=Github-leverandør
Name[nds]=Github-Anbeder
Name[nl]=Github-leverancier
Name[pl]=Dostawca Github
Name[pt]=Fornecedor do GitHub
Name[pt_BR]=Fornecedor do Github
Name[sk]=Poskytovateľ Github
Name[sl]=Ponudnik za Github
Name[sv]=Github-leverantör
Name[uk]=Надавач даних Github
Name[x-test]=xxGithub Providerxx
Name[zh_TW]=Github 提供者
GenericName=Github Provider
GenericName[bs]=Github pružalac
GenericName[ca]=Proveïdor de Github
GenericName[ca@valencia]=Proveïdor de Github
GenericName[cs]=Poskytovatel Github
GenericName[da]=Github-udbyder
GenericName[de]=GitHub-Provider
GenericName[el]=Πάροχος Github
GenericName[en_GB]=Github Provider
GenericName[es]=Proveedor de Github
GenericName[et]=Githubi pakkuja
GenericName[fi]=Github-tarjoaja
GenericName[fr]=Fournisseur Github
GenericName[gl]=Fornecedor de Github
GenericName[hu]=Github szolgáltató
GenericName[it]=Fornitore Github
GenericName[kk]=Github таратушысы
GenericName[nb]=Github-leverandør
GenericName[nds]=Github-Anbeder
GenericName[nl]=Github-leverancier
GenericName[pl]=Dostawca Github
GenericName[pt]=Fornecedor do GitHub
GenericName[pt_BR]=Fornecedor do Github
GenericName[sk]=Poskytovateľ Github
GenericName[sl]=Ponudnik za Github
GenericName[sv]=Github-leverantör
GenericName[uk]=Надавач даних Github
GenericName[x-test]=xxGithub Providerxx
GenericName[zh_TW]=Github 提供者
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevghprovider
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevghprovider
X-KDE-PluginInfo-Author=Miquel Sabaté
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Mode=GUI
X-KDevelop-Interfaces=org.kdevelop.IProjectProvider
X-KDevelop-IRequired=org.kdevelop.IBasicVersionControl@kdevgit
